# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from .. import core
from ..core.api_error import ApiError
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.http_response import AsyncHttpResponse, HttpResponse
from ..core.pydantic_utilities import parse_obj_as
from ..core.request_options import RequestOptions
from ..errors.unprocessable_entity_error import UnprocessableEntityError
from ..types.create_custom_voice_out import CreateCustomVoiceOut
from ..types.gender import Gender
from ..types.http_validation_error import HttpValidationError
from ..types.languages import Languages
from .types.list_voices_list_voices_get_response_item import ListVoicesListVoicesGetResponseItem

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawVoiceCloningClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def list_voices(
        self, *, run_id: typing.Optional[int] = None, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[typing.List[ListVoicesListVoicesGetResponseItem]]:
        """
        Parameters
        ----------
        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[typing.List[ListVoicesListVoicesGetResponseItem]]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "list-voices",
            method="GET",
            params={
                "run_id": run_id,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.List[ListVoicesListVoicesGetResponseItem],
                    parse_obj_as(
                        type_=typing.List[ListVoicesListVoicesGetResponseItem],  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def create_custom_voice(
        self,
        *,
        voice_name: str,
        gender: Gender,
        file: core.File,
        run_id: typing.Optional[int] = None,
        description: typing.Optional[str] = OMIT,
        publish_voice_to_market_place: typing.Optional[bool] = OMIT,
        age: typing.Optional[int] = OMIT,
        language: typing.Optional[Languages] = OMIT,
        enhance_audio: typing.Optional[bool] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[CreateCustomVoiceOut]:
        """
        Parameters
        ----------
        voice_name : str

        gender : Gender

        file : core.File
            See core.File for more documentation

        run_id : typing.Optional[int]

        description : typing.Optional[str]

        publish_voice_to_market_place : typing.Optional[bool]
            By setting true, you consent to making this voice available for other users in the marketplace.

        age : typing.Optional[int]

        language : typing.Optional[Languages]
            Language of the voice

        enhance_audio : typing.Optional[bool]
            Enables advanced audio processing to enhance the clarity and quality of the cloned voice output. When set to `true`, additional processing is applied to improve the overall sound experience.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[CreateCustomVoiceOut]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "create-custom-voice",
            method="POST",
            params={
                "run_id": run_id,
            },
            data={
                "voice_name": voice_name,
                "gender": gender,
                "description": description,
                "publish_voice_to_market_place": publish_voice_to_market_place,
                "age": age,
                "language": language,
                "enhance_audio": enhance_audio,
            },
            files={
                "file": file,
            },
            request_options=request_options,
            omit=OMIT,
            force_multipart=True,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    CreateCustomVoiceOut,
                    parse_obj_as(
                        type_=CreateCustomVoiceOut,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawVoiceCloningClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def list_voices(
        self, *, run_id: typing.Optional[int] = None, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[typing.List[ListVoicesListVoicesGetResponseItem]]:
        """
        Parameters
        ----------
        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[typing.List[ListVoicesListVoicesGetResponseItem]]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "list-voices",
            method="GET",
            params={
                "run_id": run_id,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.List[ListVoicesListVoicesGetResponseItem],
                    parse_obj_as(
                        type_=typing.List[ListVoicesListVoicesGetResponseItem],  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def create_custom_voice(
        self,
        *,
        voice_name: str,
        gender: Gender,
        file: core.File,
        run_id: typing.Optional[int] = None,
        description: typing.Optional[str] = OMIT,
        publish_voice_to_market_place: typing.Optional[bool] = OMIT,
        age: typing.Optional[int] = OMIT,
        language: typing.Optional[Languages] = OMIT,
        enhance_audio: typing.Optional[bool] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[CreateCustomVoiceOut]:
        """
        Parameters
        ----------
        voice_name : str

        gender : Gender

        file : core.File
            See core.File for more documentation

        run_id : typing.Optional[int]

        description : typing.Optional[str]

        publish_voice_to_market_place : typing.Optional[bool]
            By setting true, you consent to making this voice available for other users in the marketplace.

        age : typing.Optional[int]

        language : typing.Optional[Languages]
            Language of the voice

        enhance_audio : typing.Optional[bool]
            Enables advanced audio processing to enhance the clarity and quality of the cloned voice output. When set to `true`, additional processing is applied to improve the overall sound experience.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[CreateCustomVoiceOut]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "create-custom-voice",
            method="POST",
            params={
                "run_id": run_id,
            },
            data={
                "voice_name": voice_name,
                "gender": gender,
                "description": description,
                "publish_voice_to_market_place": publish_voice_to_market_place,
                "age": age,
                "language": language,
                "enhance_audio": enhance_audio,
            },
            files={
                "file": file,
            },
            request_options=request_options,
            omit=OMIT,
            force_multipart=True,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    CreateCustomVoiceOut,
                    parse_obj_as(
                        type_=CreateCustomVoiceOut,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import httpx
from .core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .core.request_options import RequestOptions
from .environment import CambApiEnvironment
from .raw_client import AsyncRawCambApi, RawCambApi

if typing.TYPE_CHECKING:
    from .audio_separation.client import AsyncAudioSeparationClient, AudioSeparationClient
    from .deprecated_streaming.client import AsyncDeprecatedStreamingClient, DeprecatedStreamingClient
    from .dictionaries.client import AsyncDictionariesClient, DictionariesClient
    from .dub.client import AsyncDubClient, DubClient
    from .folders.client import AsyncFoldersClient, FoldersClient
    from .languages.client import AsyncLanguagesClient, LanguagesClient
    from .project_setup.client import AsyncProjectSetupClient, ProjectSetupClient
    from .story.client import AsyncStoryClient, StoryClient
    from .streaming.client import AsyncStreamingClient, StreamingClient
    from .text_to_audio.client import AsyncTextToAudioClient, TextToAudioClient
    from .text_to_speech.client import AsyncTextToSpeechClient, TextToSpeechClient
    from .text_to_voice.client import AsyncTextToVoiceClient, TextToVoiceClient
    from .transcription.client import AsyncTranscriptionClient, TranscriptionClient
    from .translated_story.client import AsyncTranslatedStoryClient, TranslatedStoryClient
    from .translated_tts.client import AsyncTranslatedTtsClient, TranslatedTtsClient
    from .translation.client import AsyncTranslationClient, TranslationClient
    from .voice_cloning.client import AsyncVoiceCloningClient, VoiceCloningClient
    from .listen.client import AsyncListenClient, ListenClient

def save_stream_to_file(stream: typing.Iterable[bytes], filename: str) -> None:
    """Saves a byte stream to a file.

    Parameters
    ----------
    stream : typing.Iterable[bytes]
        The byte stream to save.
    filename : str
        The name of the file to save the stream to.
    """
    with open(filename, "wb") as f:
        for chunk in stream:
            f.write(chunk)
        
async def save_async_stream_to_file(stream: typing.AsyncIterable[bytes], filename: str) -> None:
    """Saves an async byte stream to a file.

    Parameters
    ----------
    stream : typing.AsyncIterable[bytes]
        The async byte stream to save.
    filename : str
        The name of the file to save the stream to.
    """
    with open(filename, "wb") as f:
        async for chunk in stream:
            f.write(chunk)

class CambAI:
    """
    Use this class to access the different functions within the SDK. You can instantiate any number of clients with different configuration that will propagate to these functions.

    Parameters
    ----------
    base_url : typing.Optional[str]
        The base url to use for requests from the client.

    environment : CambApiEnvironment
        The environment to use for requests from the client. from .environment import CambApiEnvironment



        Defaults to CambApiEnvironment.DEFAULT



    api_key : str
    headers : typing.Optional[typing.Dict[str, str]]
        Additional headers to send with every request.

    timeout : typing.Optional[float]
        The timeout to be used, in seconds, for requests. By default the timeout is 60 seconds, unless a custom httpx client is used, in which case this default is not enforced.

    follow_redirects : typing.Optional[bool]
        Whether the default httpx client follows redirects or not, this is irrelevant if a custom httpx client is passed in.

    httpx_client : typing.Optional[httpx.Client]
        The httpx client to use for making requests, a preconfigured client is used by default, however this is useful should you want to pass in any custom httpx configuration.

    Examples
    --------
    from camb import CambApi

    client = CambApi(
        api_key="YOUR_API_KEY",
    )
    """

    def __init__(
        self,
        *,
        base_url: typing.Optional[str] = None,
        environment: CambApiEnvironment = CambApiEnvironment.DEFAULT,
        api_key: str,
        headers: typing.Optional[typing.Dict[str, str]] = None,
        timeout: typing.Optional[float] = None,
        follow_redirects: typing.Optional[bool] = True,
        httpx_client: typing.Optional[httpx.Client] = None,
    ):
        _defaulted_timeout = (
            timeout if timeout is not None else 60 if httpx_client is None else httpx_client.timeout.read
        )
        self._client_wrapper = SyncClientWrapper(
            base_url=_get_base_url(base_url=base_url, environment=environment),
            api_key=api_key,
            headers=headers,
            httpx_client=httpx_client
            if httpx_client is not None
            else httpx.Client(timeout=_defaulted_timeout, follow_redirects=follow_redirects)
            if follow_redirects is not None
            else httpx.Client(timeout=_defaulted_timeout),
            timeout=_defaulted_timeout,
        )
        self._raw_client = RawCambApi(client_wrapper=self._client_wrapper)
        self._audio_separation: typing.Optional[AudioSeparationClient] = None
        self._dub: typing.Optional[DubClient] = None
        self._folders: typing.Optional[FoldersClient] = None
        self._languages: typing.Optional[LanguagesClient] = None
        self._story: typing.Optional[StoryClient] = None
        self._translated_story: typing.Optional[TranslatedStoryClient] = None
        self._text_to_audio: typing.Optional[TextToAudioClient] = None
        self._text_to_voice: typing.Optional[TextToVoiceClient] = None
        self._text_to_speech: typing.Optional[TextToSpeechClient] = None
        self._translation: typing.Optional[TranslationClient] = None
        self._transcription: typing.Optional[TranscriptionClient] = None
        self._translated_tts: typing.Optional[TranslatedTtsClient] = None
        self._streaming: typing.Optional[StreamingClient] = None
        self._voice_cloning: typing.Optional[VoiceCloningClient] = None
        self._dictionaries: typing.Optional[DictionariesClient] = None
        self._project_setup: typing.Optional[ProjectSetupClient] = None
        self._deprecated_streaming: typing.Optional[DeprecatedStreamingClient] = None
        self._listen: typing.Optional[ListenClient] = None

    @property
    def with_raw_response(self) -> RawCambApi:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawCambApi
        """
        return self._raw_client

    def get_swagger_docs_docs_get(self, *, request_options: typing.Optional[RequestOptions] = None) -> typing.Any:
        """
        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Any
            Successful Response

        Examples
        --------
        from camb import CambApi

        client = CambApi(
            api_key="YOUR_API_KEY",
        )
        client.get_swagger_docs_docs_get()
        """
        _response = self._raw_client.get_swagger_docs_docs_get(request_options=request_options)
        return _response.data

    def get_redoc_docs_redocs_get(self, *, request_options: typing.Optional[RequestOptions] = None) -> typing.Any:
        """
        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Any
            Successful Response

        Examples
        --------
        from camb import CambApi

        client = CambApi(
            api_key="YOUR_API_KEY",
        )
        client.get_redoc_docs_redocs_get()
        """
        _response = self._raw_client.get_redoc_docs_redocs_get(request_options=request_options)
        return _response.data

    def get_openapi_schema_openapi_json_get(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.Any:
        """
        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Any
            Successful Response

        Examples
        --------
        from camb import CambApi

        client = CambApi(
            api_key="YOUR_API_KEY",
        )
        client.get_openapi_schema_openapi_json_get()
        """
        _response = self._raw_client.get_openapi_schema_openapi_json_get(request_options=request_options)
        return _response.data

    @property
    def audio_separation(self):
        if self._audio_separation is None:
            from .audio_separation.client import AudioSeparationClient  # noqa: E402

            self._audio_separation = AudioSeparationClient(client_wrapper=self._client_wrapper)
        return self._audio_separation

    @property
    def dub(self):
        if self._dub is None:
            from .dub.client import DubClient  # noqa: E402

            self._dub = DubClient(client_wrapper=self._client_wrapper)
        return self._dub

    @property
    def folders(self):
        if self._folders is None:
            from .folders.client import FoldersClient  # noqa: E402

            self._folders = FoldersClient(client_wrapper=self._client_wrapper)
        return self._folders

    @property
    def languages(self):
        if self._languages is None:
            from .languages.client import LanguagesClient  # noqa: E402

            self._languages = LanguagesClient(client_wrapper=self._client_wrapper)
        return self._languages

    @property
    def story(self):
        if self._story is None:
            from .story.client import StoryClient  # noqa: E402

            self._story = StoryClient(client_wrapper=self._client_wrapper)
        return self._story

    @property
    def translated_story(self):
        if self._translated_story is None:
            from .translated_story.client import TranslatedStoryClient  # noqa: E402

            self._translated_story = TranslatedStoryClient(client_wrapper=self._client_wrapper)
        return self._translated_story

    @property
    def text_to_audio(self):
        if self._text_to_audio is None:
            from .text_to_audio.client import TextToAudioClient  # noqa: E402

            self._text_to_audio = TextToAudioClient(client_wrapper=self._client_wrapper)
        return self._text_to_audio

    @property
    def text_to_voice(self):
        if self._text_to_voice is None:
            from .text_to_voice.client import TextToVoiceClient  # noqa: E402

            self._text_to_voice = TextToVoiceClient(client_wrapper=self._client_wrapper)
        return self._text_to_voice

    @property
    def text_to_speech(self):
        if self._text_to_speech is None:
            from .text_to_speech.client import TextToSpeechClient  # noqa: E402

            self._text_to_speech = TextToSpeechClient(client_wrapper=self._client_wrapper)
        return self._text_to_speech

    @property
    def translation(self):
        if self._translation is None:
            from .translation.client import TranslationClient  # noqa: E402

            self._translation = TranslationClient(client_wrapper=self._client_wrapper)
        return self._translation

    @property
    def transcription(self):
        if self._transcription is None:
            from .transcription.client import TranscriptionClient  # noqa: E402

            self._transcription = TranscriptionClient(client_wrapper=self._client_wrapper)
        return self._transcription

    @property
    def translated_tts(self):
        if self._translated_tts is None:
            from .translated_tts.client import TranslatedTtsClient  # noqa: E402

            self._translated_tts = TranslatedTtsClient(client_wrapper=self._client_wrapper)
        return self._translated_tts

    @property
    def streaming(self):
        if self._streaming is None:
            from .streaming.client import StreamingClient  # noqa: E402

            self._streaming = StreamingClient(client_wrapper=self._client_wrapper)
        return self._streaming

    @property
    def voice_cloning(self):
        if self._voice_cloning is None:
            from .voice_cloning.client import VoiceCloningClient  # noqa: E402

            self._voice_cloning = VoiceCloningClient(client_wrapper=self._client_wrapper)
        return self._voice_cloning

    @property
    def dictionaries(self):
        if self._dictionaries is None:
            from .dictionaries.client import DictionariesClient  # noqa: E402

            self._dictionaries = DictionariesClient(client_wrapper=self._client_wrapper)
        return self._dictionaries

    @property
    def project_setup(self):
        if self._project_setup is None:
            from .project_setup.client import ProjectSetupClient  # noqa: E402

            self._project_setup = ProjectSetupClient(client_wrapper=self._client_wrapper)
        return self._project_setup

    @property
    def deprecated_streaming(self):
        if self._deprecated_streaming is None:
            from .deprecated_streaming.client import DeprecatedStreamingClient  # noqa: E402

            self._deprecated_streaming = DeprecatedStreamingClient(client_wrapper=self._client_wrapper)
        return self._deprecated_streaming

    @property
    def listen(self):
        if self._listen is None:
            from .listen.client import ListenClient  # noqa: E402

            self._listen = ListenClient(client_wrapper=self._client_wrapper)
        return self._listen


class AsyncCambAI:
    """
    Use this class to access the different functions within the SDK. You can instantiate any number of clients with different configuration that will propagate to these functions.

    Parameters
    ----------
    base_url : typing.Optional[str]
        The base url to use for requests from the client.

    environment : CambApiEnvironment
        The environment to use for requests from the client. from .environment import CambApiEnvironment



        Defaults to CambApiEnvironment.DEFAULT



    api_key : str
    headers : typing.Optional[typing.Dict[str, str]]
        Additional headers to send with every request.

    timeout : typing.Optional[float]
        The timeout to be used, in seconds, for requests. By default the timeout is 60 seconds, unless a custom httpx client is used, in which case this default is not enforced.

    follow_redirects : typing.Optional[bool]
        Whether the default httpx client follows redirects or not, this is irrelevant if a custom httpx client is passed in.

    httpx_client : typing.Optional[httpx.AsyncClient]
        The httpx client to use for making requests, a preconfigured client is used by default, however this is useful should you want to pass in any custom httpx configuration.

    Examples
    --------
    from camb import AsyncCambApi

    client = AsyncCambApi(
        api_key="YOUR_API_KEY",
    )
    """

    def __init__(
        self,
        *,
        base_url: typing.Optional[str] = None,
        environment: CambApiEnvironment = CambApiEnvironment.DEFAULT,
        api_key: str,
        headers: typing.Optional[typing.Dict[str, str]] = None,
        timeout: typing.Optional[float] = None,
        follow_redirects: typing.Optional[bool] = True,
        httpx_client: typing.Optional[httpx.AsyncClient] = None,
    ):
        _defaulted_timeout = (
            timeout if timeout is not None else 60 if httpx_client is None else httpx_client.timeout.read
        )
        self._client_wrapper = AsyncClientWrapper(
            base_url=_get_base_url(base_url=base_url, environment=environment),
            api_key=api_key,
            headers=headers,
            httpx_client=httpx_client
            if httpx_client is not None
            else httpx.AsyncClient(timeout=_defaulted_timeout, follow_redirects=follow_redirects)
            if follow_redirects is not None
            else httpx.AsyncClient(timeout=_defaulted_timeout),
            timeout=_defaulted_timeout,
        )
        self._raw_client = AsyncRawCambApi(client_wrapper=self._client_wrapper)
        self._audio_separation: typing.Optional[AsyncAudioSeparationClient] = None
        self._dub: typing.Optional[AsyncDubClient] = None
        self._folders: typing.Optional[AsyncFoldersClient] = None
        self._languages: typing.Optional[AsyncLanguagesClient] = None
        self._story: typing.Optional[AsyncStoryClient] = None
        self._translated_story: typing.Optional[AsyncTranslatedStoryClient] = None
        self._text_to_audio: typing.Optional[AsyncTextToAudioClient] = None
        self._text_to_voice: typing.Optional[AsyncTextToVoiceClient] = None
        self._text_to_speech: typing.Optional[AsyncTextToSpeechClient] = None
        self._translation: typing.Optional[AsyncTranslationClient] = None
        self._transcription: typing.Optional[AsyncTranscriptionClient] = None
        self._translated_tts: typing.Optional[AsyncTranslatedTtsClient] = None
        self._streaming: typing.Optional[AsyncStreamingClient] = None
        self._voice_cloning: typing.Optional[AsyncVoiceCloningClient] = None
        self._dictionaries: typing.Optional[AsyncDictionariesClient] = None
        self._project_setup: typing.Optional[AsyncProjectSetupClient] = None
        self._deprecated_streaming: typing.Optional[AsyncDeprecatedStreamingClient] = None
        self._listen: typing.Optional[AsyncListenClient] = None

    @property
    def with_raw_response(self) -> AsyncRawCambApi:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawCambApi
        """
        return self._raw_client

    async def get_swagger_docs_docs_get(self, *, request_options: typing.Optional[RequestOptions] = None) -> typing.Any:
        """
        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Any
            Successful Response

        Examples
        --------
        import asyncio

        from camb import AsyncCambApi

        client = AsyncCambApi(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.get_swagger_docs_docs_get()


        asyncio.run(main())
        """
        _response = await self._raw_client.get_swagger_docs_docs_get(request_options=request_options)
        return _response.data

    async def get_redoc_docs_redocs_get(self, *, request_options: typing.Optional[RequestOptions] = None) -> typing.Any:
        """
        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Any
            Successful Response

        Examples
        --------
        import asyncio

        from camb import AsyncCambApi

        client = AsyncCambApi(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.get_redoc_docs_redocs_get()


        asyncio.run(main())
        """
        _response = await self._raw_client.get_redoc_docs_redocs_get(request_options=request_options)
        return _response.data

    async def get_openapi_schema_openapi_json_get(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.Any:
        """
        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Any
            Successful Response

        Examples
        --------
        import asyncio

        from camb import AsyncCambApi

        client = AsyncCambApi(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.get_openapi_schema_openapi_json_get()


        asyncio.run(main())
        """
        _response = await self._raw_client.get_openapi_schema_openapi_json_get(request_options=request_options)
        return _response.data

    @property
    def audio_separation(self):
        if self._audio_separation is None:
            from .audio_separation.client import AsyncAudioSeparationClient  # noqa: E402

            self._audio_separation = AsyncAudioSeparationClient(client_wrapper=self._client_wrapper)
        return self._audio_separation

    @property
    def dub(self):
        if self._dub is None:
            from .dub.client import AsyncDubClient  # noqa: E402

            self._dub = AsyncDubClient(client_wrapper=self._client_wrapper)
        return self._dub

    @property
    def folders(self):
        if self._folders is None:
            from .folders.client import AsyncFoldersClient  # noqa: E402

            self._folders = AsyncFoldersClient(client_wrapper=self._client_wrapper)
        return self._folders

    @property
    def languages(self):
        if self._languages is None:
            from .languages.client import AsyncLanguagesClient  # noqa: E402

            self._languages = AsyncLanguagesClient(client_wrapper=self._client_wrapper)
        return self._languages

    @property
    def story(self):
        if self._story is None:
            from .story.client import AsyncStoryClient  # noqa: E402

            self._story = AsyncStoryClient(client_wrapper=self._client_wrapper)
        return self._story

    @property
    def translated_story(self):
        if self._translated_story is None:
            from .translated_story.client import AsyncTranslatedStoryClient  # noqa: E402

            self._translated_story = AsyncTranslatedStoryClient(client_wrapper=self._client_wrapper)
        return self._translated_story

    @property
    def text_to_audio(self):
        if self._text_to_audio is None:
            from .text_to_audio.client import AsyncTextToAudioClient  # noqa: E402

            self._text_to_audio = AsyncTextToAudioClient(client_wrapper=self._client_wrapper)
        return self._text_to_audio

    @property
    def text_to_voice(self):
        if self._text_to_voice is None:
            from .text_to_voice.client import AsyncTextToVoiceClient  # noqa: E402

            self._text_to_voice = AsyncTextToVoiceClient(client_wrapper=self._client_wrapper)
        return self._text_to_voice

    @property
    def text_to_speech(self):
        if self._text_to_speech is None:
            from .text_to_speech.client import AsyncTextToSpeechClient  # noqa: E402

            self._text_to_speech = AsyncTextToSpeechClient(client_wrapper=self._client_wrapper)
        return self._text_to_speech

    @property
    def translation(self):
        if self._translation is None:
            from .translation.client import AsyncTranslationClient  # noqa: E402

            self._translation = AsyncTranslationClient(client_wrapper=self._client_wrapper)
        return self._translation

    @property
    def transcription(self):
        if self._transcription is None:
            from .transcription.client import AsyncTranscriptionClient  # noqa: E402

            self._transcription = AsyncTranscriptionClient(client_wrapper=self._client_wrapper)
        return self._transcription

    @property
    def translated_tts(self):
        if self._translated_tts is None:
            from .translated_tts.client import AsyncTranslatedTtsClient  # noqa: E402

            self._translated_tts = AsyncTranslatedTtsClient(client_wrapper=self._client_wrapper)
        return self._translated_tts

    @property
    def streaming(self):
        if self._streaming is None:
            from .streaming.client import AsyncStreamingClient  # noqa: E402

            self._streaming = AsyncStreamingClient(client_wrapper=self._client_wrapper)
        return self._streaming

    @property
    def voice_cloning(self):
        if self._voice_cloning is None:
            from .voice_cloning.client import AsyncVoiceCloningClient  # noqa: E402

            self._voice_cloning = AsyncVoiceCloningClient(client_wrapper=self._client_wrapper)
        return self._voice_cloning

    @property
    def dictionaries(self):
        if self._dictionaries is None:
            from .dictionaries.client import AsyncDictionariesClient  # noqa: E402

            self._dictionaries = AsyncDictionariesClient(client_wrapper=self._client_wrapper)
        return self._dictionaries

    @property
    def project_setup(self):
        if self._project_setup is None:
            from .project_setup.client import AsyncProjectSetupClient  # noqa: E402

            self._project_setup = AsyncProjectSetupClient(client_wrapper=self._client_wrapper)
        return self._project_setup

    @property
    def deprecated_streaming(self):
        if self._deprecated_streaming is None:
            from .deprecated_streaming.client import AsyncDeprecatedStreamingClient  # noqa: E402

            self._deprecated_streaming = AsyncDeprecatedStreamingClient(client_wrapper=self._client_wrapper)
        return self._deprecated_streaming

    @property
    def listen(self):
        if self._listen is None:
            from .listen.client import AsyncListenClient  # noqa: E402

            self._listen = AsyncListenClient(client_wrapper=self._client_wrapper)
        return self._listen


def _get_base_url(*, base_url: typing.Optional[str] = None, environment: CambApiEnvironment) -> str:
    if base_url is not None:
        return base_url
    elif environment is not None:
        return environment.value
    else:
        raise Exception("Please pass in either base_url or environment to construct the client")



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .audio_stream import AudioStream
from .data_stream import DataStream
from .video_stream import VideoStream


class GetProbeStreamOut(UniversalBaseModel):
    video_streams: typing.List[VideoStream]
    audio_streams: typing.List[AudioStream]
    data_streams: typing.List[DataStream]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



from setuptools import setup, find_packages
from pathlib import Path

this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text()

setup(
    name="camb-sdk",
    long_description=long_description,
    long_description_content_type='text/markdown',
    version="1.5.1",
    packages=find_packages(where="."),
    package_dir={"": "."},
    install_requires=[
        "httpx>=0.21.2",
        "pydantic>=1.10.0",
        "typing_extensions>=4.0.0",
        "websockets>=11.0.3",
        "websocket-client>=1.6.0",
    ],
    package_data={"camb": ["py.typed"]},
    include_package_data=True,
    python_requires=">=3.8",
)



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ..core.api_error import ApiError
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.http_response import AsyncHttpResponse, HttpResponse
from ..core.jsonable_encoder import jsonable_encoder
from ..core.pydantic_utilities import parse_obj_as
from ..core.request_options import RequestOptions
from ..errors.unprocessable_entity_error import UnprocessableEntityError
from ..types.add_target_language_out import AddTargetLanguageOut
from ..types.http_validation_error import HttpValidationError
from ..types.languages import Languages
from ..types.orchestrator_pipeline_result import OrchestratorPipelineResult

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawTranslatedStoryClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def create_translation_for_existing_story(
        self,
        run_id: typing.Optional[int],
        *,
        target_language: Languages,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[AddTargetLanguageOut]:
        """
        Parameters
        ----------
        run_id : typing.Optional[int]

        target_language : Languages

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[AddTargetLanguageOut]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"translated-story/{jsonable_encoder(run_id)}",
            method="POST",
            json={
                "target_language": target_language,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    AddTargetLanguageOut,
                    parse_obj_as(
                        type_=AddTargetLanguageOut,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get_translated_story_status(
        self,
        task_id: str,
        *,
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[OrchestratorPipelineResult]:
        """
        Parameters
        ----------
        task_id : str

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[OrchestratorPipelineResult]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"translated-story/{jsonable_encoder(task_id)}",
            method="GET",
            params={
                "run_id": run_id,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    OrchestratorPipelineResult,
                    parse_obj_as(
                        type_=OrchestratorPipelineResult,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get_translated_story_run_info(
        self,
        run_id: typing.Optional[int],
        target_language: Languages,
        *,
        include_transcript: typing.Optional[bool] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[typing.Dict[str, typing.Any]]:
        """
        Parameters
        ----------
        run_id : typing.Optional[int]

        target_language : Languages

        include_transcript : typing.Optional[bool]
            Whether to include the transcription in the response for fetching the result of a Stories Translation run.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[typing.Dict[str, typing.Any]]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"translated-story-result/{jsonable_encoder(run_id)}/{jsonable_encoder(target_language)}",
            method="GET",
            params={
                "include_transcript": include_transcript,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.Dict[str, typing.Any],
                    parse_obj_as(
                        type_=typing.Dict[str, typing.Any],  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawTranslatedStoryClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def create_translation_for_existing_story(
        self,
        run_id: typing.Optional[int],
        *,
        target_language: Languages,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[AddTargetLanguageOut]:
        """
        Parameters
        ----------
        run_id : typing.Optional[int]

        target_language : Languages

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[AddTargetLanguageOut]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"translated-story/{jsonable_encoder(run_id)}",
            method="POST",
            json={
                "target_language": target_language,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    AddTargetLanguageOut,
                    parse_obj_as(
                        type_=AddTargetLanguageOut,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get_translated_story_status(
        self,
        task_id: str,
        *,
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[OrchestratorPipelineResult]:
        """
        Parameters
        ----------
        task_id : str

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[OrchestratorPipelineResult]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"translated-story/{jsonable_encoder(task_id)}",
            method="GET",
            params={
                "run_id": run_id,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    OrchestratorPipelineResult,
                    parse_obj_as(
                        type_=OrchestratorPipelineResult,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get_translated_story_run_info(
        self,
        run_id: typing.Optional[int],
        target_language: Languages,
        *,
        include_transcript: typing.Optional[bool] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[typing.Dict[str, typing.Any]]:
        """
        Parameters
        ----------
        run_id : typing.Optional[int]

        target_language : Languages

        include_transcript : typing.Optional[bool]
            Whether to include the transcription in the response for fetching the result of a Stories Translation run.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[typing.Dict[str, typing.Any]]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"translated-story-result/{jsonable_encoder(run_id)}/{jsonable_encoder(target_language)}",
            method="GET",
            params={
                "include_transcript": include_transcript,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.Dict[str, typing.Any],
                    parse_obj_as(
                        type_=typing.Dict[str, typing.Any],  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import typing

from .. import core
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.dictionary_with_terms import DictionaryWithTerms
from ..types.term_translation_input import TermTranslationInput
from .raw_client import AsyncRawDictionariesClient, RawDictionariesClient

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class DictionariesClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawDictionariesClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawDictionariesClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawDictionariesClient
        """
        return self._raw_client

    def get_dictionaries(
        self, *, run_id: typing.Optional[int] = None, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.List[DictionaryWithTerms]:
        """
        Parameters
        ----------
        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[DictionaryWithTerms]
            Successful Response

        Examples
        --------
        from camb import CambApi

        client = CambApi(
            api_key="YOUR_API_KEY",
        )
        client.dictionaries.get_dictionaries()
        """
        _response = self._raw_client.get_dictionaries(run_id=run_id, request_options=request_options)
        return _response.data

    def create_dictionary_from_file(
        self,
        *,
        dictionary_file: core.File,
        dictionary_name: str,
        run_id: typing.Optional[int] = None,
        dictionary_description: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.Any:
        """
        Parameters
        ----------
        dictionary_file : core.File
            See core.File for more documentation

        dictionary_name : str
            The name of the dictonary to be created. This is mainly used for organizational purposes.

        run_id : typing.Optional[int]

        dictionary_description : typing.Optional[str]
            The description of the dictionary to be created. This is an optional field that is used to help you provide some info about your dictionaries for better organization.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Any
            Successful Response

        Examples
        --------
        from camb import CambApi

        client = CambApi(
            api_key="YOUR_API_KEY",
        )
        client.dictionaries.create_dictionary_from_file(
            dictionary_name="dictionary_name",
        )
        """
        _response = self._raw_client.create_dictionary_from_file(
            dictionary_file=dictionary_file,
            dictionary_name=dictionary_name,
            run_id=run_id,
            dictionary_description=dictionary_description,
            request_options=request_options,
        )
        return _response.data

    def get_dictionary_info(
        self,
        dictionary_id: int,
        *,
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> DictionaryWithTerms:
        """
        Parameters
        ----------
        dictionary_id : int

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        DictionaryWithTerms
            Successful Response

        Examples
        --------
        from camb import CambApi

        client = CambApi(
            api_key="YOUR_API_KEY",
        )
        client.dictionaries.get_dictionary_info(
            dictionary_id=1,
        )
        """
        _response = self._raw_client.get_dictionary_info(dictionary_id, run_id=run_id, request_options=request_options)
        return _response.data

    def delete_dictionary(
        self,
        dictionary_id: int,
        *,
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.Any:
        """
        Parameters
        ----------
        dictionary_id : int

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Any
            Successful Response

        Examples
        --------
        from camb import CambApi

        client = CambApi(
            api_key="YOUR_API_KEY",
        )
        client.dictionaries.delete_dictionary(
            dictionary_id=1,
        )
        """
        _response = self._raw_client.delete_dictionary(dictionary_id, run_id=run_id, request_options=request_options)
        return _response.data

    def get_dictionary_details(
        self,
        dictionary_id: int,
        *,
        limit: typing.Optional[int] = None,
        search_term: typing.Optional[str] = None,
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> DictionaryWithTerms:
        """
        Parameters
        ----------
        dictionary_id : int

        limit : typing.Optional[int]
            Limit how many terms are returned when fetching the dictionary details.

        search_term : typing.Optional[str]

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        DictionaryWithTerms
            Successful Response

        Examples
        --------
        from camb import CambApi

        client = CambApi(
            api_key="YOUR_API_KEY",
        )
        client.dictionaries.get_dictionary_details(
            dictionary_id=1,
        )
        """
        _response = self._raw_client.get_dictionary_details(
            dictionary_id, limit=limit, search_term=search_term, run_id=run_id, request_options=request_options
        )
        return _response.data

    def add_term_to_dictionary(
        self,
        dictionary_id: int,
        *,
        translations: typing.Sequence[TermTranslationInput],
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.Any:
        """
        Parameters
        ----------
        dictionary_id : int

        translations : typing.Sequence[TermTranslationInput]

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Any
            Successful Response

        Examples
        --------
        from camb import CambApi, TermTranslationInput

        client = CambApi(
            api_key="YOUR_API_KEY",
        )
        client.dictionaries.add_term_to_dictionary(
            dictionary_id=1,
            translations=[
                TermTranslationInput(
                    translation="translation",
                    language=1,
                )
            ],
        )
        """
        _response = self._raw_client.add_term_to_dictionary(
            dictionary_id, translations=translations, run_id=run_id, request_options=request_options
        )
        return _response.data

    def update_term_translation_in_dictionary_using_term_id(
        self,
        dictionary_id: int,
        term_id: int,
        *,
        translations: typing.Sequence[TermTranslationInput],
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.Any:
        """
        Parameters
        ----------
        dictionary_id : int

        term_id : int

        translations : typing.Sequence[TermTranslationInput]

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Any
            Successful Response

        Examples
        --------
        from camb import CambApi, TermTranslationInput

        client = CambApi(
            api_key="YOUR_API_KEY",
        )
        client.dictionaries.update_term_translation_in_dictionary_using_term_id(
            dictionary_id=1,
            term_id=1,
            translations=[
                TermTranslationInput(
                    translation="translation",
                    language=1,
                )
            ],
        )
        """
        _response = self._raw_client.update_term_translation_in_dictionary_using_term_id(
            dictionary_id, term_id, translations=translations, run_id=run_id, request_options=request_options
        )
        return _response.data

    def delete_dictionary_term(
        self,
        dictionary_id: int,
        term_id: int,
        *,
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.Any:
        """
        Parameters
        ----------
        dictionary_id : int

        term_id : int

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Any
            Successful Response

        Examples
        --------
        from camb import CambApi

        client = CambApi(
            api_key="YOUR_API_KEY",
        )
        client.dictionaries.delete_dictionary_term(
            dictionary_id=1,
            term_id=1,
        )
        """
        _response = self._raw_client.delete_dictionary_term(
            dictionary_id, term_id, run_id=run_id, request_options=request_options
        )
        return _response.data


class AsyncDictionariesClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawDictionariesClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawDictionariesClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawDictionariesClient
        """
        return self._raw_client

    async def get_dictionaries(
        self, *, run_id: typing.Optional[int] = None, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.List[DictionaryWithTerms]:
        """
        Parameters
        ----------
        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[DictionaryWithTerms]
            Successful Response

        Examples
        --------
        import asyncio

        from camb import AsyncCambApi

        client = AsyncCambApi(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.dictionaries.get_dictionaries()


        asyncio.run(main())
        """
        _response = await self._raw_client.get_dictionaries(run_id=run_id, request_options=request_options)
        return _response.data

    async def create_dictionary_from_file(
        self,
        *,
        dictionary_file: core.File,
        dictionary_name: str,
        run_id: typing.Optional[int] = None,
        dictionary_description: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.Any:
        """
        Parameters
        ----------
        dictionary_file : core.File
            See core.File for more documentation

        dictionary_name : str
            The name of the dictonary to be created. This is mainly used for organizational purposes.

        run_id : typing.Optional[int]

        dictionary_description : typing.Optional[str]
            The description of the dictionary to be created. This is an optional field that is used to help you provide some info about your dictionaries for better organization.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Any
            Successful Response

        Examples
        --------
        import asyncio

        from camb import AsyncCambApi

        client = AsyncCambApi(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.dictionaries.create_dictionary_from_file(
                dictionary_name="dictionary_name",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.create_dictionary_from_file(
            dictionary_file=dictionary_file,
            dictionary_name=dictionary_name,
            run_id=run_id,
            dictionary_description=dictionary_description,
            request_options=request_options,
        )
        return _response.data

    async def get_dictionary_info(
        self,
        dictionary_id: int,
        *,
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> DictionaryWithTerms:
        """
        Parameters
        ----------
        dictionary_id : int

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        DictionaryWithTerms
            Successful Response

        Examples
        --------
        import asyncio

        from camb import AsyncCambApi

        client = AsyncCambApi(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.dictionaries.get_dictionary_info(
                dictionary_id=1,
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get_dictionary_info(
            dictionary_id, run_id=run_id, request_options=request_options
        )
        return _response.data

    async def delete_dictionary(
        self,
        dictionary_id: int,
        *,
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.Any:
        """
        Parameters
        ----------
        dictionary_id : int

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Any
            Successful Response

        Examples
        --------
        import asyncio

        from camb import AsyncCambApi

        client = AsyncCambApi(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.dictionaries.delete_dictionary(
                dictionary_id=1,
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.delete_dictionary(
            dictionary_id, run_id=run_id, request_options=request_options
        )
        return _response.data

    async def get_dictionary_details(
        self,
        dictionary_id: int,
        *,
        limit: typing.Optional[int] = None,
        search_term: typing.Optional[str] = None,
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> DictionaryWithTerms:
        """
        Parameters
        ----------
        dictionary_id : int

        limit : typing.Optional[int]
            Limit how many terms are returned when fetching the dictionary details.

        search_term : typing.Optional[str]

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        DictionaryWithTerms
            Successful Response

        Examples
        --------
        import asyncio

        from camb import AsyncCambApi

        client = AsyncCambApi(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.dictionaries.get_dictionary_details(
                dictionary_id=1,
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get_dictionary_details(
            dictionary_id, limit=limit, search_term=search_term, run_id=run_id, request_options=request_options
        )
        return _response.data

    async def add_term_to_dictionary(
        self,
        dictionary_id: int,
        *,
        translations: typing.Sequence[TermTranslationInput],
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.Any:
        """
        Parameters
        ----------
        dictionary_id : int

        translations : typing.Sequence[TermTranslationInput]

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Any
            Successful Response

        Examples
        --------
        import asyncio

        from camb import AsyncCambApi, TermTranslationInput

        client = AsyncCambApi(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.dictionaries.add_term_to_dictionary(
                dictionary_id=1,
                translations=[
                    TermTranslationInput(
                        translation="translation",
                        language=1,
                    )
                ],
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.add_term_to_dictionary(
            dictionary_id, translations=translations, run_id=run_id, request_options=request_options
        )
        return _response.data

    async def update_term_translation_in_dictionary_using_term_id(
        self,
        dictionary_id: int,
        term_id: int,
        *,
        translations: typing.Sequence[TermTranslationInput],
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.Any:
        """
        Parameters
        ----------
        dictionary_id : int

        term_id : int

        translations : typing.Sequence[TermTranslationInput]

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Any
            Successful Response

        Examples
        --------
        import asyncio

        from camb import AsyncCambApi, TermTranslationInput

        client = AsyncCambApi(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.dictionaries.update_term_translation_in_dictionary_using_term_id(
                dictionary_id=1,
                term_id=1,
                translations=[
                    TermTranslationInput(
                        translation="translation",
                        language=1,
                    )
                ],
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.update_term_translation_in_dictionary_using_term_id(
            dictionary_id, term_id, translations=translations, run_id=run_id, request_options=request_options
        )
        return _response.data

    async def delete_dictionary_term(
        self,
        dictionary_id: int,
        term_id: int,
        *,
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.Any:
        """
        Parameters
        ----------
        dictionary_id : int

        term_id : int

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Any
            Successful Response

        Examples
        --------
        import asyncio

        from camb import AsyncCambApi

        client = AsyncCambApi(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.dictionaries.delete_dictionary_term(
                dictionary_id=1,
                term_id=1,
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.delete_dictionary_term(
            dictionary_id, term_id, run_id=run_id, request_options=request_options
        )
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.get_tts_result_out_file_url import GetTtsResultOutFileUrl

GetTtsResultsTtsResultsPostResponseValue = typing.Union[str, GetTtsResultOutFileUrl]



# This file was auto-generated by Fern from our API Definition.

import contextlib
import typing
from json.decoder import JSONDecodeError

from ..core.api_error import ApiError
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.http_response import AsyncHttpResponse, HttpResponse
from ..core.jsonable_encoder import jsonable_encoder
from ..core.pydantic_utilities import parse_obj_as
from ..core.request_options import RequestOptions
from ..core.serialization import convert_and_respect_annotation_metadata
from ..errors.unprocessable_entity_error import UnprocessableEntityError
from ..types.create_tts_out import CreateTtsOut
from ..types.gender import Gender
from ..types.http_validation_error import HttpValidationError
from ..types.languages import Languages
from ..types.orchestrator_pipeline_result import OrchestratorPipelineResult
from ..types.stream_tts_inference_options import StreamTtsInferenceOptions
from ..types.stream_tts_output_configuration import StreamTtsOutputConfiguration
from ..types.stream_tts_voice_settings import StreamTtsVoiceSettings
from .types.create_stream_tts_request_payload_language import CreateStreamTtsRequestPayloadLanguage
from .types.create_stream_tts_request_payload_speech_model import CreateStreamTtsRequestPayloadSpeechModel
from .types.get_tts_results_tts_results_post_response_value import GetTtsResultsTtsResultsPostResponseValue
from .types.get_tts_run_info_tts_result_run_id_get_response import GetTtsRunInfoTtsResultRunIdGetResponse

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawTextToSpeechClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    @contextlib.contextmanager
    def tts(
        self,
        *,
        text: str,
        language: CreateStreamTtsRequestPayloadLanguage,
        voice_id: int,
        speech_model: typing.Optional[CreateStreamTtsRequestPayloadSpeechModel] = OMIT,
        user_instructions: typing.Optional[str] = OMIT,
        enhance_named_entities_pronunciation: typing.Optional[bool] = OMIT,
        output_configuration: typing.Optional[StreamTtsOutputConfiguration] = OMIT,
        voice_settings: typing.Optional[StreamTtsVoiceSettings] = OMIT,
        inference_options: typing.Optional[StreamTtsInferenceOptions] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.Iterator[HttpResponse[typing.Iterator[bytes]]]:
        """
        Parameters
        ----------
        text : str

        language : CreateStreamTtsRequestPayloadLanguage

        voice_id : int

        speech_model : typing.Optional[CreateStreamTtsRequestPayloadSpeechModel]

        user_instructions : typing.Optional[str]

        enhance_named_entities_pronunciation : typing.Optional[bool]

        output_configuration : typing.Optional[StreamTtsOutputConfiguration]

        voice_settings : typing.Optional[StreamTtsVoiceSettings]

        inference_options : typing.Optional[StreamTtsInferenceOptions]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration. You can pass in configuration such as `chunk_size`, and more to customize the request and response.

        Returns
        -------
        typing.Iterator[HttpResponse[typing.Iterator[bytes]]]
            Streaming audio response
        """
        with self._client_wrapper.httpx_client.stream(
            "tts-stream",
            method="POST",
            json={
                "text": text,
                "language": language,
                "voice_id": voice_id,
                "speech_model": speech_model,
                "user_instructions": user_instructions,
                "enhance_named_entities_pronunciation": enhance_named_entities_pronunciation,
                "output_configuration": convert_and_respect_annotation_metadata(
                    object_=output_configuration, annotation=StreamTtsOutputConfiguration, direction="write"
                ),
                "voice_settings": convert_and_respect_annotation_metadata(
                    object_=voice_settings, annotation=StreamTtsVoiceSettings, direction="write"
                ),
                "inference_options": convert_and_respect_annotation_metadata(
                    object_=inference_options, annotation=StreamTtsInferenceOptions, direction="write"
                ),
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        ) as _response:

            def _stream() -> HttpResponse[typing.Iterator[bytes]]:
                try:
                    if 200 <= _response.status_code < 300:
                        _chunk_size = request_options.get("chunk_size", None) if request_options is not None else None
                        return HttpResponse(
                            response=_response, data=(_chunk for _chunk in _response.iter_bytes(chunk_size=_chunk_size))
                        )
                    _response.read()
                    if _response.status_code == 422:
                        raise UnprocessableEntityError(
                            headers=dict(_response.headers),
                            body=typing.cast(
                                HttpValidationError,
                                parse_obj_as(
                                    type_=HttpValidationError,  # type: ignore
                                    object_=_response.json(),
                                ),
                            ),
                        )
                    _response_json = _response.json()
                except JSONDecodeError:
                    raise ApiError(
                        status_code=_response.status_code, headers=dict(_response.headers), body=_response.text
                    )
                raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

            yield _stream()

    def create_tts(
        self,
        *,
        text: str,
        voice_id: int,
        language: Languages,
        run_id: typing.Optional[int] = None,
        project_name: typing.Optional[str] = OMIT,
        project_description: typing.Optional[str] = OMIT,
        folder_id: typing.Optional[int] = OMIT,
        gender: typing.Optional[Gender] = OMIT,
        age: typing.Optional[int] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[CreateTtsOut]:
        """
        Parameters
        ----------
        text : str

        voice_id : int

        language : Languages

        run_id : typing.Optional[int]

        project_name : typing.Optional[str]

        project_description : typing.Optional[str]

        folder_id : typing.Optional[int]

        gender : typing.Optional[Gender]

        age : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[CreateTtsOut]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "tts",
            method="POST",
            params={
                "run_id": run_id,
            },
            json={
                "project_name": project_name,
                "project_description": project_description,
                "folder_id": folder_id,
                "text": text,
                "voice_id": voice_id,
                "language": language,
                "gender": gender,
                "age": age,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    CreateTtsOut,
                    parse_obj_as(
                        type_=CreateTtsOut,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get_tts_result(
        self,
        task_id: str,
        *,
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[OrchestratorPipelineResult]:
        """
        Parameters
        ----------
        task_id : str

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[OrchestratorPipelineResult]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"tts/{jsonable_encoder(task_id)}",
            method="GET",
            params={
                "run_id": run_id,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    OrchestratorPipelineResult,
                    parse_obj_as(
                        type_=OrchestratorPipelineResult,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get_tts_run_info(
        self,
        run_id: typing.Optional[int],
        *,
        output_type: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[GetTtsRunInfoTtsResultRunIdGetResponse]:
        """
        Retrieves the result of a Text To Speech (TTS) run.

        This endpoint validates the provided `run_id` and fetches the corresponding TTS-generated audio.
        The user must have valid access to the run. The function supports two output formats:
        - `RAW_BYTES`: Streams the audio file directly.
        - `FILE_URL`: Returns a pre-signed URL to download the audio file.

        Args:
            run_id (int): Unique identifier for the TTS run.
            api_key_obj (dict): API key object used for authentication and storage preferences.
            traceparent (Optional[str]): Traceparent header for distributed tracing.
            output_type (OutputType, optional): Determines the output format. Defaults to `RAW_BYTES`.

        Returns:
            StreamingResponse | GetTTSOut:
                - If `output_type = RAW_BYTES`: A streaming response containing the TTS-generated audio in FLAC format.
                - If `output_type = FILE_URL`: A URL pointing to the stored TTS-generated audio file.

        Raises:
            HTTPException:
                - 400 BAD REQUEST if the run ID is invalid or does not belong to a TTS process.
                - 500 INTERNAL SERVER ERROR if fetching or streaming the audio fails.

        Assumptions:
            - The user has valid access to the `run_id`.
            - The `run_id` corresponds to a valid TTS run.
            - There is only **one** dialogue associated with the given `run_id`.

        Parameters
        ----------
        run_id : typing.Optional[int]

        output_type : typing.Optional[str]
            Output format for the Text To Speech result

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[GetTtsRunInfoTtsResultRunIdGetResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"tts-result/{jsonable_encoder(run_id)}",
            method="GET",
            params={
                "output_type": output_type,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    GetTtsRunInfoTtsResultRunIdGetResponse,
                    parse_obj_as(
                        type_=GetTtsRunInfoTtsResultRunIdGetResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get_tts_results(
        self,
        *,
        run_ids: typing.Sequence[int],
        run_id: typing.Optional[int] = None,
        traceparent: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[typing.Dict[str, GetTtsResultsTtsResultsPostResponseValue]]:
        """
        Parameters
        ----------
        run_ids : typing.Sequence[int]

        run_id : typing.Optional[int]

        traceparent : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[typing.Dict[str, GetTtsResultsTtsResultsPostResponseValue]]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "tts-results",
            method="POST",
            params={
                "run_id": run_id,
            },
            json={
                "run_ids": run_ids,
            },
            headers={
                "content-type": "application/json",
                "traceparent": str(traceparent) if traceparent is not None else None,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.Dict[str, GetTtsResultsTtsResultsPostResponseValue],
                    parse_obj_as(
                        type_=typing.Dict[str, GetTtsResultsTtsResultsPostResponseValue],  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get_tts_result_discord(
        self,
        task_id: str,
        *,
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[OrchestratorPipelineResult]:
        """
        Parameters
        ----------
        task_id : str

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[OrchestratorPipelineResult]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"discord/tts/{jsonable_encoder(task_id)}",
            method="GET",
            params={
                "run_id": run_id,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    OrchestratorPipelineResult,
                    parse_obj_as(
                        type_=OrchestratorPipelineResult,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawTextToSpeechClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    @contextlib.asynccontextmanager
    async def tts(
        self,
        *,
        text: str,
        language: CreateStreamTtsRequestPayloadLanguage,
        voice_id: int,
        speech_model: typing.Optional[CreateStreamTtsRequestPayloadSpeechModel] = OMIT,
        user_instructions: typing.Optional[str] = OMIT,
        enhance_named_entities_pronunciation: typing.Optional[bool] = OMIT,
        output_configuration: typing.Optional[StreamTtsOutputConfiguration] = OMIT,
        voice_settings: typing.Optional[StreamTtsVoiceSettings] = OMIT,
        inference_options: typing.Optional[StreamTtsInferenceOptions] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.AsyncIterator[AsyncHttpResponse[typing.AsyncIterator[bytes]]]:
        """
        Parameters
        ----------
        text : str

        language : CreateStreamTtsRequestPayloadLanguage

        voice_id : int

        speech_model : typing.Optional[CreateStreamTtsRequestPayloadSpeechModel]

        user_instructions : typing.Optional[str]

        enhance_named_entities_pronunciation : typing.Optional[bool]

        output_configuration : typing.Optional[StreamTtsOutputConfiguration]

        voice_settings : typing.Optional[StreamTtsVoiceSettings]

        inference_options : typing.Optional[StreamTtsInferenceOptions]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration. You can pass in configuration such as `chunk_size`, and more to customize the request and response.

        Returns
        -------
        typing.AsyncIterator[AsyncHttpResponse[typing.AsyncIterator[bytes]]]
            Streaming audio response
        """
        async with self._client_wrapper.httpx_client.stream(
            "tts-stream",
            method="POST",
            json={
                "text": text,
                "language": language,
                "voice_id": voice_id,
                "speech_model": speech_model,
                "user_instructions": user_instructions,
                "enhance_named_entities_pronunciation": enhance_named_entities_pronunciation,
                "output_configuration": convert_and_respect_annotation_metadata(
                    object_=output_configuration, annotation=StreamTtsOutputConfiguration, direction="write"
                ),
                "voice_settings": convert_and_respect_annotation_metadata(
                    object_=voice_settings, annotation=StreamTtsVoiceSettings, direction="write"
                ),
                "inference_options": convert_and_respect_annotation_metadata(
                    object_=inference_options, annotation=StreamTtsInferenceOptions, direction="write"
                ),
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        ) as _response:

            async def _stream() -> AsyncHttpResponse[typing.AsyncIterator[bytes]]:
                try:
                    if 200 <= _response.status_code < 300:
                        _chunk_size = request_options.get("chunk_size", None) if request_options is not None else None
                        return AsyncHttpResponse(
                            response=_response,
                            data=(_chunk async for _chunk in _response.aiter_bytes(chunk_size=_chunk_size)),
                        )
                    await _response.aread()
                    if _response.status_code == 422:
                        raise UnprocessableEntityError(
                            headers=dict(_response.headers),
                            body=typing.cast(
                                HttpValidationError,
                                parse_obj_as(
                                    type_=HttpValidationError,  # type: ignore
                                    object_=_response.json(),
                                ),
                            ),
                        )
                    _response_json = _response.json()
                except JSONDecodeError:
                    raise ApiError(
                        status_code=_response.status_code, headers=dict(_response.headers), body=_response.text
                    )
                raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

            yield await _stream()

    async def create_tts(
        self,
        *,
        text: str,
        voice_id: int,
        language: Languages,
        run_id: typing.Optional[int] = None,
        project_name: typing.Optional[str] = OMIT,
        project_description: typing.Optional[str] = OMIT,
        folder_id: typing.Optional[int] = OMIT,
        gender: typing.Optional[Gender] = OMIT,
        age: typing.Optional[int] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[CreateTtsOut]:
        """
        Parameters
        ----------
        text : str

        voice_id : int

        language : Languages

        run_id : typing.Optional[int]

        project_name : typing.Optional[str]

        project_description : typing.Optional[str]

        folder_id : typing.Optional[int]

        gender : typing.Optional[Gender]

        age : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[CreateTtsOut]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "tts",
            method="POST",
            params={
                "run_id": run_id,
            },
            json={
                "project_name": project_name,
                "project_description": project_description,
                "folder_id": folder_id,
                "text": text,
                "voice_id": voice_id,
                "language": language,
                "gender": gender,
                "age": age,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    CreateTtsOut,
                    parse_obj_as(
                        type_=CreateTtsOut,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get_tts_result(
        self,
        task_id: str,
        *,
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[OrchestratorPipelineResult]:
        """
        Parameters
        ----------
        task_id : str

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[OrchestratorPipelineResult]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"tts/{jsonable_encoder(task_id)}",
            method="GET",
            params={
                "run_id": run_id,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    OrchestratorPipelineResult,
                    parse_obj_as(
                        type_=OrchestratorPipelineResult,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get_tts_run_info(
        self,
        run_id: typing.Optional[int],
        *,
        output_type: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[GetTtsRunInfoTtsResultRunIdGetResponse]:
        """
        Retrieves the result of a Text To Speech (TTS) run.

        This endpoint validates the provided `run_id` and fetches the corresponding TTS-generated audio.
        The user must have valid access to the run. The function supports two output formats:
        - `RAW_BYTES`: Streams the audio file directly.
        - `FILE_URL`: Returns a pre-signed URL to download the audio file.

        Args:
            run_id (int): Unique identifier for the TTS run.
            api_key_obj (dict): API key object used for authentication and storage preferences.
            traceparent (Optional[str]): Traceparent header for distributed tracing.
            output_type (OutputType, optional): Determines the output format. Defaults to `RAW_BYTES`.

        Returns:
            StreamingResponse | GetTTSOut:
                - If `output_type = RAW_BYTES`: A streaming response containing the TTS-generated audio in FLAC format.
                - If `output_type = FILE_URL`: A URL pointing to the stored TTS-generated audio file.

        Raises:
            HTTPException:
                - 400 BAD REQUEST if the run ID is invalid or does not belong to a TTS process.
                - 500 INTERNAL SERVER ERROR if fetching or streaming the audio fails.

        Assumptions:
            - The user has valid access to the `run_id`.
            - The `run_id` corresponds to a valid TTS run.
            - There is only **one** dialogue associated with the given `run_id`.

        Parameters
        ----------
        run_id : typing.Optional[int]

        output_type : typing.Optional[str]
            Output format for the Text To Speech result

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[GetTtsRunInfoTtsResultRunIdGetResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"tts-result/{jsonable_encoder(run_id)}",
            method="GET",
            params={
                "output_type": output_type,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    GetTtsRunInfoTtsResultRunIdGetResponse,
                    parse_obj_as(
                        type_=GetTtsRunInfoTtsResultRunIdGetResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get_tts_results(
        self,
        *,
        run_ids: typing.Sequence[int],
        run_id: typing.Optional[int] = None,
        traceparent: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[typing.Dict[str, GetTtsResultsTtsResultsPostResponseValue]]:
        """
        Parameters
        ----------
        run_ids : typing.Sequence[int]

        run_id : typing.Optional[int]

        traceparent : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[typing.Dict[str, GetTtsResultsTtsResultsPostResponseValue]]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "tts-results",
            method="POST",
            params={
                "run_id": run_id,
            },
            json={
                "run_ids": run_ids,
            },
            headers={
                "content-type": "application/json",
                "traceparent": str(traceparent) if traceparent is not None else None,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.Dict[str, GetTtsResultsTtsResultsPostResponseValue],
                    parse_obj_as(
                        type_=typing.Dict[str, GetTtsResultsTtsResultsPostResponseValue],  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get_tts_result_discord(
        self,
        task_id: str,
        *,
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[OrchestratorPipelineResult]:
        """
        Parameters
        ----------
        task_id : str

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[OrchestratorPipelineResult]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"discord/tts/{jsonable_encoder(task_id)}",
            method="GET",
            params={
                "run_id": run_id,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    OrchestratorPipelineResult,
                    parse_obj_as(
                        type_=OrchestratorPipelineResult,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import json
from dataclasses import dataclass
from typing import Any, Optional


@dataclass(frozen=True)
class ServerSentEvent:
    event: str = "message"
    data: str = ""
    id: str = ""
    retry: Optional[int] = None

    def json(self) -> Any:
        """Parse the data field as JSON."""
        return json.loads(self.data)



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from .. import core
from ..core.api_error import ApiError
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.http_response import AsyncHttpResponse, HttpResponse
from ..core.jsonable_encoder import jsonable_encoder
from ..core.pydantic_utilities import parse_obj_as
from ..core.request_options import RequestOptions
from ..errors.unprocessable_entity_error import UnprocessableEntityError
from ..types.http_validation_error import HttpValidationError
from ..types.languages import Languages
from ..types.orchestrator_pipeline_result import OrchestratorPipelineResult
from .types.create_story_story_post_response import CreateStoryStoryPostResponse
from .types.setup_story_story_setup_post_response import SetupStoryStorySetupPostResponse

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawStoryClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def create_story(
        self,
        *,
        file: core.File,
        source_language: Languages,
        run_id: typing.Optional[int] = None,
        title: typing.Optional[str] = OMIT,
        description: typing.Optional[str] = OMIT,
        narrator_voice_id: typing.Optional[int] = OMIT,
        folder_id: typing.Optional[int] = OMIT,
        chosen_dictionaries: typing.Optional[typing.List[int]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[CreateStoryStoryPostResponse]:
        """
        Parameters
        ----------
        file : core.File
            See core.File for more documentation

        source_language : Languages

        run_id : typing.Optional[int]

        title : typing.Optional[str]

        description : typing.Optional[str]

        narrator_voice_id : typing.Optional[int]

        folder_id : typing.Optional[int]

        chosen_dictionaries : typing.Optional[typing.List[int]]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[CreateStoryStoryPostResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "story",
            method="POST",
            params={
                "run_id": run_id,
            },
            data={
                "source_language": source_language,
                "title": title,
                "description": description,
                "narrator_voice_id": narrator_voice_id,
                "folder_id": folder_id,
                "chosen_dictionaries": chosen_dictionaries,
            },
            files={
                "file": file,
            },
            request_options=request_options,
            omit=OMIT,
            force_multipart=True,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    CreateStoryStoryPostResponse,
                    parse_obj_as(
                        type_=CreateStoryStoryPostResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def setup_story(
        self,
        *,
        file: core.File,
        source_language: Languages,
        run_id: typing.Optional[int] = None,
        title: typing.Optional[str] = OMIT,
        description: typing.Optional[str] = OMIT,
        narrator_voice_id: typing.Optional[int] = OMIT,
        folder_id: typing.Optional[int] = OMIT,
        chosen_dictionaries: typing.Optional[typing.List[int]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[SetupStoryStorySetupPostResponse]:
        """
        Parameters
        ----------
        file : core.File
            See core.File for more documentation

        source_language : Languages

        run_id : typing.Optional[int]

        title : typing.Optional[str]

        description : typing.Optional[str]

        narrator_voice_id : typing.Optional[int]

        folder_id : typing.Optional[int]

        chosen_dictionaries : typing.Optional[typing.List[int]]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[SetupStoryStorySetupPostResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "story-setup",
            method="POST",
            params={
                "run_id": run_id,
            },
            data={
                "source_language": source_language,
                "title": title,
                "description": description,
                "narrator_voice_id": narrator_voice_id,
                "folder_id": folder_id,
                "chosen_dictionaries": chosen_dictionaries,
            },
            files={
                "file": file,
            },
            request_options=request_options,
            omit=OMIT,
            force_multipart=True,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    SetupStoryStorySetupPostResponse,
                    parse_obj_as(
                        type_=SetupStoryStorySetupPostResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get_story_status(
        self,
        task_id: str,
        *,
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[OrchestratorPipelineResult]:
        """
        Parameters
        ----------
        task_id : str

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[OrchestratorPipelineResult]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"story/{jsonable_encoder(task_id)}",
            method="GET",
            params={
                "run_id": run_id,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    OrchestratorPipelineResult,
                    parse_obj_as(
                        type_=OrchestratorPipelineResult,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get_story_run_info(
        self,
        run_id: typing.Optional[int],
        *,
        include_transcript: typing.Optional[bool] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[typing.Dict[str, typing.Any]]:
        """
        Parameters
        ----------
        run_id : typing.Optional[int]

        include_transcript : typing.Optional[bool]
            Whether to include the transcription in the response for fetching the result of a Stories run.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[typing.Dict[str, typing.Any]]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"story-result/{jsonable_encoder(run_id)}",
            method="GET",
            params={
                "include_transcript": include_transcript,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.Dict[str, typing.Any],
                    parse_obj_as(
                        type_=typing.Dict[str, typing.Any],  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get_stories_runs_results(
        self,
        *,
        run_ids: typing.Sequence[int],
        run_id: typing.Optional[int] = None,
        traceparent: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[typing.Dict[str, typing.Dict[str, typing.Any]]]:
        """
        Parameters
        ----------
        run_ids : typing.Sequence[int]

        run_id : typing.Optional[int]

        traceparent : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[typing.Dict[str, typing.Dict[str, typing.Any]]]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "stories-results",
            method="POST",
            params={
                "run_id": run_id,
            },
            json={
                "run_ids": run_ids,
            },
            headers={
                "content-type": "application/json",
                "traceparent": str(traceparent) if traceparent is not None else None,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.Dict[str, typing.Dict[str, typing.Any]],
                    parse_obj_as(
                        type_=typing.Dict[str, typing.Dict[str, typing.Any]],  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawStoryClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def create_story(
        self,
        *,
        file: core.File,
        source_language: Languages,
        run_id: typing.Optional[int] = None,
        title: typing.Optional[str] = OMIT,
        description: typing.Optional[str] = OMIT,
        narrator_voice_id: typing.Optional[int] = OMIT,
        folder_id: typing.Optional[int] = OMIT,
        chosen_dictionaries: typing.Optional[typing.List[int]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[CreateStoryStoryPostResponse]:
        """
        Parameters
        ----------
        file : core.File
            See core.File for more documentation

        source_language : Languages

        run_id : typing.Optional[int]

        title : typing.Optional[str]

        description : typing.Optional[str]

        narrator_voice_id : typing.Optional[int]

        folder_id : typing.Optional[int]

        chosen_dictionaries : typing.Optional[typing.List[int]]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[CreateStoryStoryPostResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "story",
            method="POST",
            params={
                "run_id": run_id,
            },
            data={
                "source_language": source_language,
                "title": title,
                "description": description,
                "narrator_voice_id": narrator_voice_id,
                "folder_id": folder_id,
                "chosen_dictionaries": chosen_dictionaries,
            },
            files={
                "file": file,
            },
            request_options=request_options,
            omit=OMIT,
            force_multipart=True,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    CreateStoryStoryPostResponse,
                    parse_obj_as(
                        type_=CreateStoryStoryPostResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def setup_story(
        self,
        *,
        file: core.File,
        source_language: Languages,
        run_id: typing.Optional[int] = None,
        title: typing.Optional[str] = OMIT,
        description: typing.Optional[str] = OMIT,
        narrator_voice_id: typing.Optional[int] = OMIT,
        folder_id: typing.Optional[int] = OMIT,
        chosen_dictionaries: typing.Optional[typing.List[int]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[SetupStoryStorySetupPostResponse]:
        """
        Parameters
        ----------
        file : core.File
            See core.File for more documentation

        source_language : Languages

        run_id : typing.Optional[int]

        title : typing.Optional[str]

        description : typing.Optional[str]

        narrator_voice_id : typing.Optional[int]

        folder_id : typing.Optional[int]

        chosen_dictionaries : typing.Optional[typing.List[int]]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[SetupStoryStorySetupPostResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "story-setup",
            method="POST",
            params={
                "run_id": run_id,
            },
            data={
                "source_language": source_language,
                "title": title,
                "description": description,
                "narrator_voice_id": narrator_voice_id,
                "folder_id": folder_id,
                "chosen_dictionaries": chosen_dictionaries,
            },
            files={
                "file": file,
            },
            request_options=request_options,
            omit=OMIT,
            force_multipart=True,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    SetupStoryStorySetupPostResponse,
                    parse_obj_as(
                        type_=SetupStoryStorySetupPostResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get_story_status(
        self,
        task_id: str,
        *,
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[OrchestratorPipelineResult]:
        """
        Parameters
        ----------
        task_id : str

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[OrchestratorPipelineResult]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"story/{jsonable_encoder(task_id)}",
            method="GET",
            params={
                "run_id": run_id,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    OrchestratorPipelineResult,
                    parse_obj_as(
                        type_=OrchestratorPipelineResult,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get_story_run_info(
        self,
        run_id: typing.Optional[int],
        *,
        include_transcript: typing.Optional[bool] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[typing.Dict[str, typing.Any]]:
        """
        Parameters
        ----------
        run_id : typing.Optional[int]

        include_transcript : typing.Optional[bool]
            Whether to include the transcription in the response for fetching the result of a Stories run.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[typing.Dict[str, typing.Any]]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"story-result/{jsonable_encoder(run_id)}",
            method="GET",
            params={
                "include_transcript": include_transcript,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.Dict[str, typing.Any],
                    parse_obj_as(
                        type_=typing.Dict[str, typing.Any],  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get_stories_runs_results(
        self,
        *,
        run_ids: typing.Sequence[int],
        run_id: typing.Optional[int] = None,
        traceparent: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[typing.Dict[str, typing.Dict[str, typing.Any]]]:
        """
        Parameters
        ----------
        run_ids : typing.Sequence[int]

        run_id : typing.Optional[int]

        traceparent : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[typing.Dict[str, typing.Dict[str, typing.Any]]]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "stories-results",
            method="POST",
            params={
                "run_id": run_id,
            },
            json={
                "run_ids": run_ids,
            },
            headers={
                "content-type": "application/json",
                "traceparent": str(traceparent) if traceparent is not None else None,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.Dict[str, typing.Dict[str, typing.Any]],
                    parse_obj_as(
                        type_=typing.Dict[str, typing.Dict[str, typing.Any]],  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import typing

from .. import core
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.languages import Languages
from ..types.orchestrator_pipeline_result import OrchestratorPipelineResult
from .raw_client import AsyncRawStoryClient, RawStoryClient
from .types.create_story_story_post_response import CreateStoryStoryPostResponse
from .types.setup_story_story_setup_post_response import SetupStoryStorySetupPostResponse

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class StoryClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawStoryClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawStoryClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawStoryClient
        """
        return self._raw_client

    def create_story(
        self,
        *,
        file: core.File,
        source_language: Languages,
        run_id: typing.Optional[int] = None,
        title: typing.Optional[str] = OMIT,
        description: typing.Optional[str] = OMIT,
        narrator_voice_id: typing.Optional[int] = OMIT,
        folder_id: typing.Optional[int] = OMIT,
        chosen_dictionaries: typing.Optional[typing.List[int]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> CreateStoryStoryPostResponse:
        """
        Parameters
        ----------
        file : core.File
            See core.File for more documentation

        source_language : Languages

        run_id : typing.Optional[int]

        title : typing.Optional[str]

        description : typing.Optional[str]

        narrator_voice_id : typing.Optional[int]

        folder_id : typing.Optional[int]

        chosen_dictionaries : typing.Optional[typing.List[int]]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        CreateStoryStoryPostResponse
            Successful Response

        Examples
        --------
        from camb import CambApi

        client = CambApi(
            api_key="YOUR_API_KEY",
        )
        client.story.create_story(
            source_language=1,
        )
        """
        _response = self._raw_client.create_story(
            file=file,
            source_language=source_language,
            run_id=run_id,
            title=title,
            description=description,
            narrator_voice_id=narrator_voice_id,
            folder_id=folder_id,
            chosen_dictionaries=chosen_dictionaries,
            request_options=request_options,
        )
        return _response.data

    def setup_story(
        self,
        *,
        file: core.File,
        source_language: Languages,
        run_id: typing.Optional[int] = None,
        title: typing.Optional[str] = OMIT,
        description: typing.Optional[str] = OMIT,
        narrator_voice_id: typing.Optional[int] = OMIT,
        folder_id: typing.Optional[int] = OMIT,
        chosen_dictionaries: typing.Optional[typing.List[int]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SetupStoryStorySetupPostResponse:
        """
        Parameters
        ----------
        file : core.File
            See core.File for more documentation

        source_language : Languages

        run_id : typing.Optional[int]

        title : typing.Optional[str]

        description : typing.Optional[str]

        narrator_voice_id : typing.Optional[int]

        folder_id : typing.Optional[int]

        chosen_dictionaries : typing.Optional[typing.List[int]]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SetupStoryStorySetupPostResponse
            Successful Response

        Examples
        --------
        from camb import CambApi

        client = CambApi(
            api_key="YOUR_API_KEY",
        )
        client.story.setup_story(
            source_language=1,
        )
        """
        _response = self._raw_client.setup_story(
            file=file,
            source_language=source_language,
            run_id=run_id,
            title=title,
            description=description,
            narrator_voice_id=narrator_voice_id,
            folder_id=folder_id,
            chosen_dictionaries=chosen_dictionaries,
            request_options=request_options,
        )
        return _response.data

    def get_story_status(
        self,
        task_id: str,
        *,
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> OrchestratorPipelineResult:
        """
        Parameters
        ----------
        task_id : str

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        OrchestratorPipelineResult
            Successful Response

        Examples
        --------
        from camb import CambApi

        client = CambApi(
            api_key="YOUR_API_KEY",
        )
        client.story.get_story_status(
            task_id="task_id",
        )
        """
        _response = self._raw_client.get_story_status(task_id, run_id=run_id, request_options=request_options)
        return _response.data

    def get_story_run_info(
        self,
        run_id: typing.Optional[int],
        *,
        include_transcript: typing.Optional[bool] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.Dict[str, typing.Any]:
        """
        Parameters
        ----------
        run_id : typing.Optional[int]

        include_transcript : typing.Optional[bool]
            Whether to include the transcription in the response for fetching the result of a Stories run.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Dict[str, typing.Any]
            Successful Response

        Examples
        --------
        from camb import CambApi

        client = CambApi(
            api_key="YOUR_API_KEY",
        )
        client.story.get_story_run_info(
            run_id=1,
        )
        """
        _response = self._raw_client.get_story_run_info(
            run_id, include_transcript=include_transcript, request_options=request_options
        )
        return _response.data

    def get_stories_runs_results(
        self,
        *,
        run_ids: typing.Sequence[int],
        run_id: typing.Optional[int] = None,
        traceparent: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.Dict[str, typing.Dict[str, typing.Any]]:
        """
        Parameters
        ----------
        run_ids : typing.Sequence[int]

        run_id : typing.Optional[int]

        traceparent : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Dict[str, typing.Dict[str, typing.Any]]
            Successful Response

        Examples
        --------
        from camb import CambApi

        client = CambApi(
            api_key="YOUR_API_KEY",
        )
        client.story.get_stories_runs_results(
            run_ids=[1],
        )
        """
        _response = self._raw_client.get_stories_runs_results(
            run_ids=run_ids, run_id=run_id, traceparent=traceparent, request_options=request_options
        )
        return _response.data


class AsyncStoryClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawStoryClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawStoryClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawStoryClient
        """
        return self._raw_client

    async def create_story(
        self,
        *,
        file: core.File,
        source_language: Languages,
        run_id: typing.Optional[int] = None,
        title: typing.Optional[str] = OMIT,
        description: typing.Optional[str] = OMIT,
        narrator_voice_id: typing.Optional[int] = OMIT,
        folder_id: typing.Optional[int] = OMIT,
        chosen_dictionaries: typing.Optional[typing.List[int]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> CreateStoryStoryPostResponse:
        """
        Parameters
        ----------
        file : core.File
            See core.File for more documentation

        source_language : Languages

        run_id : typing.Optional[int]

        title : typing.Optional[str]

        description : typing.Optional[str]

        narrator_voice_id : typing.Optional[int]

        folder_id : typing.Optional[int]

        chosen_dictionaries : typing.Optional[typing.List[int]]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        CreateStoryStoryPostResponse
            Successful Response

        Examples
        --------
        import asyncio

        from camb import AsyncCambApi

        client = AsyncCambApi(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.story.create_story(
                source_language=1,
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.create_story(
            file=file,
            source_language=source_language,
            run_id=run_id,
            title=title,
            description=description,
            narrator_voice_id=narrator_voice_id,
            folder_id=folder_id,
            chosen_dictionaries=chosen_dictionaries,
            request_options=request_options,
        )
        return _response.data

    async def setup_story(
        self,
        *,
        file: core.File,
        source_language: Languages,
        run_id: typing.Optional[int] = None,
        title: typing.Optional[str] = OMIT,
        description: typing.Optional[str] = OMIT,
        narrator_voice_id: typing.Optional[int] = OMIT,
        folder_id: typing.Optional[int] = OMIT,
        chosen_dictionaries: typing.Optional[typing.List[int]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SetupStoryStorySetupPostResponse:
        """
        Parameters
        ----------
        file : core.File
            See core.File for more documentation

        source_language : Languages

        run_id : typing.Optional[int]

        title : typing.Optional[str]

        description : typing.Optional[str]

        narrator_voice_id : typing.Optional[int]

        folder_id : typing.Optional[int]

        chosen_dictionaries : typing.Optional[typing.List[int]]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SetupStoryStorySetupPostResponse
            Successful Response

        Examples
        --------
        import asyncio

        from camb import AsyncCambApi

        client = AsyncCambApi(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.story.setup_story(
                source_language=1,
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.setup_story(
            file=file,
            source_language=source_language,
            run_id=run_id,
            title=title,
            description=description,
            narrator_voice_id=narrator_voice_id,
            folder_id=folder_id,
            chosen_dictionaries=chosen_dictionaries,
            request_options=request_options,
        )
        return _response.data

    async def get_story_status(
        self,
        task_id: str,
        *,
        run_id: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> OrchestratorPipelineResult:
        """
        Parameters
        ----------
        task_id : str

        run_id : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        OrchestratorPipelineResult
            Successful Response

        Examples
        --------
        import asyncio

        from camb import AsyncCambApi

        client = AsyncCambApi(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.story.get_story_status(
                task_id="task_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get_story_status(task_id, run_id=run_id, request_options=request_options)
        return _response.data

    async def get_story_run_info(
        self,
        run_id: typing.Optional[int],
        *,
        include_transcript: typing.Optional[bool] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.Dict[str, typing.Any]:
        """
        Parameters
        ----------
        run_id : typing.Optional[int]

        include_transcript : typing.Optional[bool]
            Whether to include the transcription in the response for fetching the result of a Stories run.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Dict[str, typing.Any]
            Successful Response

        Examples
        --------
        import asyncio

        from camb import AsyncCambApi

        client = AsyncCambApi(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.story.get_story_run_info(
                run_id=1,
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get_story_run_info(
            run_id, include_transcript=include_transcript, request_options=request_options
        )
        return _response.data

    async def get_stories_runs_results(
        self,
        *,
        run_ids: typing.Sequence[int],
        run_id: typing.Optional[int] = None,
        traceparent: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.Dict[str, typing.Dict[str, typing.Any]]:
        """
        Parameters
        ----------
        run_ids : typing.Sequence[int]

        run_id : typing.Optional[int]

        traceparent : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Dict[str, typing.Dict[str, typing.Any]]
            Successful Response

        Examples
        --------
        import asyncio

        from camb import AsyncCambApi

        client = AsyncCambApi(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.story.get_stories_runs_results(
                run_ids=[1],
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get_stories_runs_results(
            run_ids=run_ids, run_id=run_id, traceparent=traceparent, request_options=request_options
        )
        return _response.data
